/** @file

hippodraw::QtSortedCheckListItem class implementation.


This class inherits the QCheckListItem class and overrides the
compare() function. It is used to sort the QListView in numerical
order.

Copyright (C) 2006   The Board of Trustees of The Leland
Stanford Junior University.  All Rights Reserved.

$Id: QtSortedCheckListItem.cxx,v 1.3 2006/05/17 14:03:45 pfkeb Exp $

*/

#include "QtSortedCheckListItem.h"

#include <cstdlib>

using namespace hippodraw;

QtSortedCheckListItem::
#if QT_VERSION < 0x040000
QtSortedCheckListItem ( QListView * parent, const QString & text ):
  QCheckListItem ( parent, text, CheckBox )
#else
QtSortedCheckListItem ( Q3ListView * parent, const QString & text ):
  Q3CheckListItem ( parent, text, CheckBox )
#endif
{
}

int 
QtSortedCheckListItem::
#if QT_VERSION < 0x040000
compare ( QListViewItem *i, int col, bool ascending ) const
#else
compare ( Q3ListViewItem *i, int col, bool ascending ) const
#endif
{
  int retVal;
  
  // Column 1 is names of data fields (text).
  if ( col == 1 ) {
#if QT_VERSION < 0x040000
    retVal = QCheckListItem::compare ( i, col, ascending );
#else
    retVal = Q3CheckListItem::compare ( i, col, ascending );
#endif
  }
  
  else {
    double a = std::atof ( key ( col, ascending ) );
    double b = std::atof ( i -> key ( col, ascending ) );
    if ( a < b )
      retVal = -1;
    else if ( a > b )
      retVal = 1;
    else
      retVal = 0;
  }

  return retVal;
}

